==> org-lsst-sal-camera-2.6.1-sources.jar: org/lsst/sal/camera/event/Chiller_timersConfigurationEvent.java <==
package org.lsst.sal.camera.event;

import org.lsst.sal.camera.CameraEvent;

public class Chiller_timersConfigurationEvent extends CameraEvent {
  private final String version;

  private final long periodictasks_agentMonitorService_taskPeriodMillis;

  private final long periodictasks_checkBurstDiscP_taskPeriodMillis;

  private final long periodictasks_checkDataArrival_taskPeriodMillis;

  private final long periodictasks_heartbeat_taskPeriodMillis;

  private final long periodictasks_monitor_check_Chiller_taskPeriodMillis;

  private final long periodictasks_monitor_check_Maq20_taskPeriodMillis;

  private final long periodictasks_monitor_check_Pluto_taskPeriodMillis;

  private final long periodictasks_monitor_publish_burstDiscs_taskPeriodMillis;

  private final long periodictasks_monitor_publish_taskPeriodMillis;

  private final long periodictasks_monitor_update_burstDiscs_taskPeriodMillis;

  private final long periodictasks_monitor_update_taskPeriodMillis;

  private final long periodictasks_runtimeInfo_taskPeriodMillis;

  private final long periodictasks_sendDutTemperature_taskPeriodMillis;

  private final long periodictasks_updateCtrlState_taskPeriodMillis;

  public Chiller_timersConfigurationEvent(String version,
      long periodictasks_agentMonitorService_taskPeriodMillis,
      long periodictasks_checkBurstDiscP_taskPeriodMillis,
      long periodictasks_checkDataArrival_taskPeriodMillis,
      long periodictasks_heartbeat_taskPeriodMillis,
      long periodictasks_monitor_check_Chiller_taskPeriodMillis,
      long periodictasks_monitor_check_Maq20_taskPeriodMillis,
      long periodictasks_monitor_check_Pluto_taskPeriodMillis,
      long periodictasks_monitor_publish_burstDiscs_taskPeriodMillis,
      long periodictasks_monitor_publish_taskPeriodMillis,
      long periodictasks_monitor_update_burstDiscs_taskPeriodMillis,
      long periodictasks_monitor_update_taskPeriodMillis,
      long periodictasks_runtimeInfo_taskPeriodMillis,
      long periodictasks_sendDutTemperature_taskPeriodMillis,
      long periodictasks_updateCtrlState_taskPeriodMillis) {
    this.version = version;
    this.periodictasks_agentMonitorService_taskPeriodMillis = periodictasks_agentMonitorService_taskPeriodMillis;
    this.periodictasks_checkBurstDiscP_taskPeriodMillis = periodictasks_checkBurstDiscP_taskPeriodMillis;
    this.periodictasks_checkDataArrival_taskPeriodMillis = periodictasks_checkDataArrival_taskPeriodMillis;
    this.periodictasks_heartbeat_taskPeriodMillis = periodictasks_heartbeat_taskPeriodMillis;
    this.periodictasks_monitor_check_Chiller_taskPeriodMillis = periodictasks_monitor_check_Chiller_taskPeriodMillis;
    this.periodictasks_monitor_check_Maq20_taskPeriodMillis = periodictasks_monitor_check_Maq20_taskPeriodMillis;
    this.periodictasks_monitor_check_Pluto_taskPeriodMillis = periodictasks_monitor_check_Pluto_taskPeriodMillis;
    this.periodictasks_monitor_publish_burstDiscs_taskPeriodMillis = periodictasks_monitor_publish_burstDiscs_taskPeriodMillis;
    this.periodictasks_monitor_publish_taskPeriodMillis = periodictasks_monitor_publish_taskPeriodMillis;
    this.periodictasks_monitor_update_burstDiscs_taskPeriodMillis = periodictasks_monitor_update_burstDiscs_taskPeriodMillis;
    this.periodictasks_monitor_update_taskPeriodMillis = periodictasks_monitor_update_taskPeriodMillis;
    this.periodictasks_runtimeInfo_taskPeriodMillis = periodictasks_runtimeInfo_taskPeriodMillis;
    this.periodictasks_sendDutTemperature_taskPeriodMillis = periodictasks_sendDutTemperature_taskPeriodMillis;
    this.periodictasks_updateCtrlState_taskPeriodMillis = periodictasks_updateCtrlState_taskPeriodMillis;
  }

  public String getVersion() {
    return version;
  }

  public long getPeriodictasks_agentMonitorService_taskPeriodMillis() {
    return periodictasks_agentMonitorService_taskPeriodMillis;
  }

  public long getPeriodictasks_checkBurstDiscP_taskPeriodMillis() {
    return periodictasks_checkBurstDiscP_taskPeriodMillis;
  }

  public long getPeriodictasks_checkDataArrival_taskPeriodMillis() {
    return periodictasks_checkDataArrival_taskPeriodMillis;
  }

  public long getPeriodictasks_heartbeat_taskPeriodMillis() {
    return periodictasks_heartbeat_taskPeriodMillis;
  }

  public long getPeriodictasks_monitor_check_Chiller_taskPeriodMillis() {
    return periodictasks_monitor_check_Chiller_taskPeriodMillis;
  }

  public long getPeriodictasks_monitor_check_Maq20_taskPeriodMillis() {
    return periodictasks_monitor_check_Maq20_taskPeriodMillis;
  }

  public long getPeriodictasks_monitor_check_Pluto_taskPeriodMillis() {
    return periodictasks_monitor_check_Pluto_taskPeriodMillis;
  }

  public long getPeriodictasks_monitor_publish_burstDiscs_taskPeriodMillis() {
    return periodictasks_monitor_publish_burstDiscs_taskPeriodMillis;
  }

  public long getPeriodictasks_monitor_publish_taskPeriodMillis() {
    return periodictasks_monitor_publish_taskPeriodMillis;
  }

  public long getPeriodictasks_monitor_update_burstDiscs_taskPeriodMillis() {
    return periodictasks_monitor_update_burstDiscs_taskPeriodMillis;
  }

  public long getPeriodictasks_monitor_update_taskPeriodMillis() {
    return periodictasks_monitor_update_taskPeriodMillis;
  }

  public long getPeriodictasks_runtimeInfo_taskPeriodMillis() {
    return periodictasks_runtimeInfo_taskPeriodMillis;
  }

  public long getPeriodictasks_sendDutTemperature_taskPeriodMillis() {
    return periodictasks_sendDutTemperature_taskPeriodMillis;
  }

  public long getPeriodictasks_updateCtrlState_taskPeriodMillis() {
    return periodictasks_updateCtrlState_taskPeriodMillis;
  }

  @Override
  public String toString() {
    return "Chiller_timersConfigurationEvent{" + "version=" + version +
        ", periodictasks_agentMonitorService_taskPeriodMillis=" + periodictasks_agentMonitorService_taskPeriodMillis +
        ", periodictasks_checkBurstDiscP_taskPeriodMillis=" + periodictasks_checkBurstDiscP_taskPeriodMillis +
        ", periodictasks_checkDataArrival_taskPeriodMillis=" + periodictasks_checkDataArrival_taskPeriodMillis +
        ", periodictasks_heartbeat_taskPeriodMillis=" + periodictasks_heartbeat_taskPeriodMillis +
        ", periodictasks_monitor_check_Chiller_taskPeriodMillis=" + periodictasks_monitor_check_Chiller_taskPeriodMillis +
        ", periodictasks_monitor_check_Maq20_taskPeriodMillis=" + periodictasks_monitor_check_Maq20_taskPeriodMillis +
        ", periodictasks_monitor_check_Pluto_taskPeriodMillis=" + periodictasks_monitor_check_Pluto_taskPeriodMillis +
        ", periodictasks_monitor_publish_burstDiscs_taskPeriodMillis=" + periodictasks_monitor_publish_burstDiscs_taskPeriodMillis +
        ", periodictasks_monitor_publish_taskPeriodMillis=" + periodictasks_monitor_publish_taskPeriodMillis +
        ", periodictasks_monitor_update_burstDiscs_taskPeriodMillis=" + periodictasks_monitor_update_burstDiscs_taskPeriodMillis +
        ", periodictasks_monitor_update_taskPeriodMillis=" + periodictasks_monitor_update_taskPeriodMillis +
        ", periodictasks_runtimeInfo_taskPeriodMillis=" + periodictasks_runtimeInfo_taskPeriodMillis +
        ", periodictasks_sendDutTemperature_taskPeriodMillis=" + periodictasks_sendDutTemperature_taskPeriodMillis +
        ", periodictasks_updateCtrlState_taskPeriodMillis=" + periodictasks_updateCtrlState_taskPeriodMillis +
        "}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private String version;

    private long periodictasks_agentMonitorService_taskPeriodMillis;

    private long periodictasks_checkBurstDiscP_taskPeriodMillis;

    private long periodictasks_checkDataArrival_taskPeriodMillis;

    private long periodictasks_heartbeat_taskPeriodMillis;

    private long periodictasks_monitor_check_Chiller_taskPeriodMillis;

    private long periodictasks_monitor_check_Maq20_taskPeriodMillis;

    private long periodictasks_monitor_check_Pluto_taskPeriodMillis;

    private long periodictasks_monitor_publish_burstDiscs_taskPeriodMillis;

    private long periodictasks_monitor_publish_taskPeriodMillis;

    private long periodictasks_monitor_update_burstDiscs_taskPeriodMillis;

    private long periodictasks_monitor_update_taskPeriodMillis;

    private long periodictasks_runtimeInfo_taskPeriodMillis;

    private long periodictasks_sendDutTemperature_taskPeriodMillis;

    private long periodictasks_updateCtrlState_taskPeriodMillis;

    private Builder() {
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder periodictasks_agentMonitorService_taskPeriodMillis(
        long periodictasks_agentMonitorService_taskPeriodMillis) {
      this.periodictasks_agentMonitorService_taskPeriodMillis = periodictasks_agentMonitorService_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_checkBurstDiscP_taskPeriodMillis(
        long periodictasks_checkBurstDiscP_taskPeriodMillis) {
      this.periodictasks_checkBurstDiscP_taskPeriodMillis = periodictasks_checkBurstDiscP_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_checkDataArrival_taskPeriodMillis(
        long periodictasks_checkDataArrival_taskPeriodMillis) {
      this.periodictasks_checkDataArrival_taskPeriodMillis = periodictasks_checkDataArrival_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_heartbeat_taskPeriodMillis(
        long periodictasks_heartbeat_taskPeriodMillis) {
      this.periodictasks_heartbeat_taskPeriodMillis = periodictasks_heartbeat_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_check_Chiller_taskPeriodMillis(
        long periodictasks_monitor_check_Chiller_taskPeriodMillis) {
      this.periodictasks_monitor_check_Chiller_taskPeriodMillis = periodictasks_monitor_check_Chiller_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_check_Maq20_taskPeriodMillis(
        long periodictasks_monitor_check_Maq20_taskPeriodMillis) {
      this.periodictasks_monitor_check_Maq20_taskPeriodMillis = periodictasks_monitor_check_Maq20_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_check_Pluto_taskPeriodMillis(
        long periodictasks_monitor_check_Pluto_taskPeriodMillis) {
      this.periodictasks_monitor_check_Pluto_taskPeriodMillis = periodictasks_monitor_check_Pluto_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_publish_burstDiscs_taskPeriodMillis(
        long periodictasks_monitor_publish_burstDiscs_taskPeriodMillis) {
      this.periodictasks_monitor_publish_burstDiscs_taskPeriodMillis = periodictasks_monitor_publish_burstDiscs_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_publish_taskPeriodMillis(
        long periodictasks_monitor_publish_taskPeriodMillis) {
      this.periodictasks_monitor_publish_taskPeriodMillis = periodictasks_monitor_publish_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_update_burstDiscs_taskPeriodMillis(
        long periodictasks_monitor_update_burstDiscs_taskPeriodMillis) {
      this.periodictasks_monitor_update_burstDiscs_taskPeriodMillis = periodictasks_monitor_update_burstDiscs_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_update_taskPeriodMillis(
        long periodictasks_monitor_update_taskPeriodMillis) {
      this.periodictasks_monitor_update_taskPeriodMillis = periodictasks_monitor_update_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_runtimeInfo_taskPeriodMillis(
        long periodictasks_runtimeInfo_taskPeriodMillis) {
      this.periodictasks_runtimeInfo_taskPeriodMillis = periodictasks_runtimeInfo_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_sendDutTemperature_taskPeriodMillis(
        long periodictasks_sendDutTemperature_taskPeriodMillis) {
      this.periodictasks_sendDutTemperature_taskPeriodMillis = periodictasks_sendDutTemperature_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_updateCtrlState_taskPeriodMillis(
        long periodictasks_updateCtrlState_taskPeriodMillis) {
      this.periodictasks_updateCtrlState_taskPeriodMillis = periodictasks_updateCtrlState_taskPeriodMillis;
      return this;
    }

    public Chiller_timersConfigurationEvent build() {
      return new Chiller_timersConfigurationEvent(version, periodictasks_agentMonitorService_taskPeriodMillis, periodictasks_checkBurstDiscP_taskPeriodMillis, periodictasks_checkDataArrival_taskPeriodMillis, periodictasks_heartbeat_taskPeriodMillis, periodictasks_monitor_check_Chiller_taskPeriodMillis, periodictasks_monitor_check_Maq20_taskPeriodMillis, periodictasks_monitor_check_Pluto_taskPeriodMillis, periodictasks_monitor_publish_burstDiscs_taskPeriodMillis, periodictasks_monitor_publish_taskPeriodMillis, periodictasks_monitor_update_burstDiscs_taskPeriodMillis, periodictasks_monitor_update_taskPeriodMillis, periodictasks_runtimeInfo_taskPeriodMillis, periodictasks_sendDutTemperature_taskPeriodMillis, periodictasks_updateCtrlState_taskPeriodMillis);
    }
  }
}

==> org-lsst-sal-camera-3.0.2-sources.jar: org/lsst/sal/camera/event/Chiller_timersConfigurationEvent.java <==
package org.lsst.sal.camera.event;

import org.lsst.sal.camera.CameraEvent;

public class Chiller_timersConfigurationEvent extends CameraEvent {
  private final String version;

  private final long periodictasks_agentMonitorService_taskPeriodMillis;

  private final long periodictasks_checkBurstDiscP_taskPeriodMillis;

  private final long periodictasks_checkDataArrival_taskPeriodMillis;

  private final long periodictasks_heartbeat_taskPeriodMillis;

  private final long periodictasks_monitor_check_Chiller_taskPeriodMillis;

  private final long periodictasks_monitor_check_Maq20_taskPeriodMillis;

  private final long periodictasks_monitor_check_Pluto_taskPeriodMillis;

  private final long periodictasks_monitor_publish_burstDiscs_taskPeriodMillis;

  private final long periodictasks_monitor_publish_taskPeriodMillis;

  private final long periodictasks_monitor_update_burstDiscs_taskPeriodMillis;

  private final long periodictasks_monitor_update_taskPeriodMillis;

  private final long periodictasks_publishParams_taskPeriodMillis;

  private final long periodictasks_runtimeInfo_taskPeriodMillis;

  private final long periodictasks_sendDutTemperature_taskPeriodMillis;

  private final long periodictasks_updateCtrlState_taskPeriodMillis;

  public Chiller_timersConfigurationEvent(String version,
      long periodictasks_agentMonitorService_taskPeriodMillis,
      long periodictasks_checkBurstDiscP_taskPeriodMillis,
      long periodictasks_checkDataArrival_taskPeriodMillis,
      long periodictasks_heartbeat_taskPeriodMillis,
      long periodictasks_monitor_check_Chiller_taskPeriodMillis,
      long periodictasks_monitor_check_Maq20_taskPeriodMillis,
      long periodictasks_monitor_check_Pluto_taskPeriodMillis,
      long periodictasks_monitor_publish_burstDiscs_taskPeriodMillis,
      long periodictasks_monitor_publish_taskPeriodMillis,
      long periodictasks_monitor_update_burstDiscs_taskPeriodMillis,
      long periodictasks_monitor_update_taskPeriodMillis,
      long periodictasks_publishParams_taskPeriodMillis,
      long periodictasks_runtimeInfo_taskPeriodMillis,
      long periodictasks_sendDutTemperature_taskPeriodMillis,
      long periodictasks_updateCtrlState_taskPeriodMillis) {
    this.version = version;
    this.periodictasks_agentMonitorService_taskPeriodMillis = periodictasks_agentMonitorService_taskPeriodMillis;
    this.periodictasks_checkBurstDiscP_taskPeriodMillis = periodictasks_checkBurstDiscP_taskPeriodMillis;
    this.periodictasks_checkDataArrival_taskPeriodMillis = periodictasks_checkDataArrival_taskPeriodMillis;
    this.periodictasks_heartbeat_taskPeriodMillis = periodictasks_heartbeat_taskPeriodMillis;
    this.periodictasks_monitor_check_Chiller_taskPeriodMillis = periodictasks_monitor_check_Chiller_taskPeriodMillis;
    this.periodictasks_monitor_check_Maq20_taskPeriodMillis = periodictasks_monitor_check_Maq20_taskPeriodMillis;
    this.periodictasks_monitor_check_Pluto_taskPeriodMillis = periodictasks_monitor_check_Pluto_taskPeriodMillis;
    this.periodictasks_monitor_publish_burstDiscs_taskPeriodMillis = periodictasks_monitor_publish_burstDiscs_taskPeriodMillis;
    this.periodictasks_monitor_publish_taskPeriodMillis = periodictasks_monitor_publish_taskPeriodMillis;
    this.periodictasks_monitor_update_burstDiscs_taskPeriodMillis = periodictasks_monitor_update_burstDiscs_taskPeriodMillis;
    this.periodictasks_monitor_update_taskPeriodMillis = periodictasks_monitor_update_taskPeriodMillis;
    this.periodictasks_publishParams_taskPeriodMillis = periodictasks_publishParams_taskPeriodMillis;
    this.periodictasks_runtimeInfo_taskPeriodMillis = periodictasks_runtimeInfo_taskPeriodMillis;
    this.periodictasks_sendDutTemperature_taskPeriodMillis = periodictasks_sendDutTemperature_taskPeriodMillis;
    this.periodictasks_updateCtrlState_taskPeriodMillis = periodictasks_updateCtrlState_taskPeriodMillis;
  }

  public String getVersion() {
    return version;
  }

  public long getPeriodictasks_agentMonitorService_taskPeriodMillis() {
    return periodictasks_agentMonitorService_taskPeriodMillis;
  }

  public long getPeriodictasks_checkBurstDiscP_taskPeriodMillis() {
    return periodictasks_checkBurstDiscP_taskPeriodMillis;
  }

  public long getPeriodictasks_checkDataArrival_taskPeriodMillis() {
    return periodictasks_checkDataArrival_taskPeriodMillis;
  }

  public long getPeriodictasks_heartbeat_taskPeriodMillis() {
    return periodictasks_heartbeat_taskPeriodMillis;
  }

  public long getPeriodictasks_monitor_check_Chiller_taskPeriodMillis() {
    return periodictasks_monitor_check_Chiller_taskPeriodMillis;
  }

  public long getPeriodictasks_monitor_check_Maq20_taskPeriodMillis() {
    return periodictasks_monitor_check_Maq20_taskPeriodMillis;
  }

  public long getPeriodictasks_monitor_check_Pluto_taskPeriodMillis() {
    return periodictasks_monitor_check_Pluto_taskPeriodMillis;
  }

  public long getPeriodictasks_monitor_publish_burstDiscs_taskPeriodMillis() {
    return periodictasks_monitor_publish_burstDiscs_taskPeriodMillis;
  }

  public long getPeriodictasks_monitor_publish_taskPeriodMillis() {
    return periodictasks_monitor_publish_taskPeriodMillis;
  }

  public long getPeriodictasks_monitor_update_burstDiscs_taskPeriodMillis() {
    return periodictasks_monitor_update_burstDiscs_taskPeriodMillis;
  }

  public long getPeriodictasks_monitor_update_taskPeriodMillis() {
    return periodictasks_monitor_update_taskPeriodMillis;
  }

  public long getPeriodictasks_publishParams_taskPeriodMillis() {
    return periodictasks_publishParams_taskPeriodMillis;
  }

  public long getPeriodictasks_runtimeInfo_taskPeriodMillis() {
    return periodictasks_runtimeInfo_taskPeriodMillis;
  }

  public long getPeriodictasks_sendDutTemperature_taskPeriodMillis() {
    return periodictasks_sendDutTemperature_taskPeriodMillis;
  }

  public long getPeriodictasks_updateCtrlState_taskPeriodMillis() {
    return periodictasks_updateCtrlState_taskPeriodMillis;
  }

  @Override
  public String toString() {
    return "Chiller_timersConfigurationEvent{" + "version=" + version +
        ", periodictasks_agentMonitorService_taskPeriodMillis=" + periodictasks_agentMonitorService_taskPeriodMillis +
        ", periodictasks_checkBurstDiscP_taskPeriodMillis=" + periodictasks_checkBurstDiscP_taskPeriodMillis +
        ", periodictasks_checkDataArrival_taskPeriodMillis=" + periodictasks_checkDataArrival_taskPeriodMillis +
        ", periodictasks_heartbeat_taskPeriodMillis=" + periodictasks_heartbeat_taskPeriodMillis +
        ", periodictasks_monitor_check_Chiller_taskPeriodMillis=" + periodictasks_monitor_check_Chiller_taskPeriodMillis +
        ", periodictasks_monitor_check_Maq20_taskPeriodMillis=" + periodictasks_monitor_check_Maq20_taskPeriodMillis +
        ", periodictasks_monitor_check_Pluto_taskPeriodMillis=" + periodictasks_monitor_check_Pluto_taskPeriodMillis +
        ", periodictasks_monitor_publish_burstDiscs_taskPeriodMillis=" + periodictasks_monitor_publish_burstDiscs_taskPeriodMillis +
        ", periodictasks_monitor_publish_taskPeriodMillis=" + periodictasks_monitor_publish_taskPeriodMillis +
        ", periodictasks_monitor_update_burstDiscs_taskPeriodMillis=" + periodictasks_monitor_update_burstDiscs_taskPeriodMillis +
        ", periodictasks_monitor_update_taskPeriodMillis=" + periodictasks_monitor_update_taskPeriodMillis +
        ", periodictasks_publishParams_taskPeriodMillis=" + periodictasks_publishParams_taskPeriodMillis +
        ", periodictasks_runtimeInfo_taskPeriodMillis=" + periodictasks_runtimeInfo_taskPeriodMillis +
        ", periodictasks_sendDutTemperature_taskPeriodMillis=" + periodictasks_sendDutTemperature_taskPeriodMillis +
        ", periodictasks_updateCtrlState_taskPeriodMillis=" + periodictasks_updateCtrlState_taskPeriodMillis +
        "}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private String version;

    private long periodictasks_agentMonitorService_taskPeriodMillis;

    private long periodictasks_checkBurstDiscP_taskPeriodMillis;

    private long periodictasks_checkDataArrival_taskPeriodMillis;

    private long periodictasks_heartbeat_taskPeriodMillis;

    private long periodictasks_monitor_check_Chiller_taskPeriodMillis;

    private long periodictasks_monitor_check_Maq20_taskPeriodMillis;

    private long periodictasks_monitor_check_Pluto_taskPeriodMillis;

    private long periodictasks_monitor_publish_burstDiscs_taskPeriodMillis;

    private long periodictasks_monitor_publish_taskPeriodMillis;

    private long periodictasks_monitor_update_burstDiscs_taskPeriodMillis;

    private long periodictasks_monitor_update_taskPeriodMillis;

    private long periodictasks_publishParams_taskPeriodMillis;

    private long periodictasks_runtimeInfo_taskPeriodMillis;

    private long periodictasks_sendDutTemperature_taskPeriodMillis;

    private long periodictasks_updateCtrlState_taskPeriodMillis;

    private Builder() {
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder periodictasks_agentMonitorService_taskPeriodMillis(
        long periodictasks_agentMonitorService_taskPeriodMillis) {
      this.periodictasks_agentMonitorService_taskPeriodMillis = periodictasks_agentMonitorService_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_checkBurstDiscP_taskPeriodMillis(
        long periodictasks_checkBurstDiscP_taskPeriodMillis) {
      this.periodictasks_checkBurstDiscP_taskPeriodMillis = periodictasks_checkBurstDiscP_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_checkDataArrival_taskPeriodMillis(
        long periodictasks_checkDataArrival_taskPeriodMillis) {
      this.periodictasks_checkDataArrival_taskPeriodMillis = periodictasks_checkDataArrival_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_heartbeat_taskPeriodMillis(
        long periodictasks_heartbeat_taskPeriodMillis) {
      this.periodictasks_heartbeat_taskPeriodMillis = periodictasks_heartbeat_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_check_Chiller_taskPeriodMillis(
        long periodictasks_monitor_check_Chiller_taskPeriodMillis) {
      this.periodictasks_monitor_check_Chiller_taskPeriodMillis = periodictasks_monitor_check_Chiller_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_check_Maq20_taskPeriodMillis(
        long periodictasks_monitor_check_Maq20_taskPeriodMillis) {
      this.periodictasks_monitor_check_Maq20_taskPeriodMillis = periodictasks_monitor_check_Maq20_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_check_Pluto_taskPeriodMillis(
        long periodictasks_monitor_check_Pluto_taskPeriodMillis) {
      this.periodictasks_monitor_check_Pluto_taskPeriodMillis = periodictasks_monitor_check_Pluto_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_publish_burstDiscs_taskPeriodMillis(
        long periodictasks_monitor_publish_burstDiscs_taskPeriodMillis) {
      this.periodictasks_monitor_publish_burstDiscs_taskPeriodMillis = periodictasks_monitor_publish_burstDiscs_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_publish_taskPeriodMillis(
        long periodictasks_monitor_publish_taskPeriodMillis) {
      this.periodictasks_monitor_publish_taskPeriodMillis = periodictasks_monitor_publish_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_update_burstDiscs_taskPeriodMillis(
        long periodictasks_monitor_update_burstDiscs_taskPeriodMillis) {
      this.periodictasks_monitor_update_burstDiscs_taskPeriodMillis = periodictasks_monitor_update_burstDiscs_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_update_taskPeriodMillis(
        long periodictasks_monitor_update_taskPeriodMillis) {
      this.periodictasks_monitor_update_taskPeriodMillis = periodictasks_monitor_update_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_publishParams_taskPeriodMillis(
        long periodictasks_publishParams_taskPeriodMillis) {
      this.periodictasks_publishParams_taskPeriodMillis = periodictasks_publishParams_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_runtimeInfo_taskPeriodMillis(
        long periodictasks_runtimeInfo_taskPeriodMillis) {
      this.periodictasks_runtimeInfo_taskPeriodMillis = periodictasks_runtimeInfo_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_sendDutTemperature_taskPeriodMillis(
        long periodictasks_sendDutTemperature_taskPeriodMillis) {
      this.periodictasks_sendDutTemperature_taskPeriodMillis = periodictasks_sendDutTemperature_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_updateCtrlState_taskPeriodMillis(
        long periodictasks_updateCtrlState_taskPeriodMillis) {
      this.periodictasks_updateCtrlState_taskPeriodMillis = periodictasks_updateCtrlState_taskPeriodMillis;
      return this;
    }

    public Chiller_timersConfigurationEvent build() {
      return new Chiller_timersConfigurationEvent(version, periodictasks_agentMonitorService_taskPeriodMillis, periodictasks_checkBurstDiscP_taskPeriodMillis, periodictasks_checkDataArrival_taskPeriodMillis, periodictasks_heartbeat_taskPeriodMillis, periodictasks_monitor_check_Chiller_taskPeriodMillis, periodictasks_monitor_check_Maq20_taskPeriodMillis, periodictasks_monitor_check_Pluto_taskPeriodMillis, periodictasks_monitor_publish_burstDiscs_taskPeriodMillis, periodictasks_monitor_publish_taskPeriodMillis, periodictasks_monitor_update_burstDiscs_taskPeriodMillis, periodictasks_monitor_update_taskPeriodMillis, periodictasks_publishParams_taskPeriodMillis, periodictasks_runtimeInfo_taskPeriodMillis, periodictasks_sendDutTemperature_taskPeriodMillis, periodictasks_updateCtrlState_taskPeriodMillis);
    }
  }
}
